@@ -11,7 +11,7 @@ struct nls_table;
 struct kstat;
 struct ksmbd_file;
 
-int match_pattern(const char *str, const char *pattern);
+int match_pattern(const char *str, size_t len, const char *pattern);
 
 int ksmbd_validate_filename(char *filename);
 
@@ -25,7 +25,7 @@ void ksmbd_conv_path_to_unix(char *path);
 void ksmbd_strip_last_slash(char *path);
 void ksmbd_conv_path_to_windows(char *path);
 
-char *extract_sharename(char *treename);
+char *ksmbd_extract_sharename(char *treename);
 
 char *convert_to_unix_name(struct ksmbd_share_config *share, char *name);
 
@@ -35,4 +35,10 @@ struct ksmbd_dir_info;
 char *ksmbd_convert_dir_info_name(struct ksmbd_dir_info *d_info,
 				  const struct nls_table *local_nls,
 				  int *conv_len);
+
+#define NTFS_TIME_OFFSET	((u64)(369 * 365 + 89) * 24 * 3600 * 10000000)
+
+struct timespec64 ksmbd_NTtimeToUnix(__le64 ntutc);
+u64 ksmbd_UnixTimeToNT(struct timespec64 t);
+long long ksmbd_systime(void);
 #endif /* __KSMBD_MISC_H__ */
