@@ -24,16 +24,15 @@ static LIST_HEAD(lease_table_list);
 static DEFINE_RWLOCK(lease_list_lock);
 
 /**
- * get_new_opinfo() - allocate a new opinfo object for oplock info
- * @conn:	connection instance
+ * alloc_opinfo() - allocate a new opinfo object for oplock info
+ * @work:	smb work
  * @id:		fid of open file
  * @Tid:	tree id of connection
- * @lctx:	lease context information
  *
  * Return:      allocated opinfo object on success, otherwise NULL
  */
 static struct oplock_info *alloc_opinfo(struct ksmbd_work *work,
-		uint64_t id, __u16 Tid)
+		u64 id, __u16 Tid)
 {
 	struct ksmbd_session *sess = work->sess;
 	struct oplock_info *opinfo;
@@ -96,8 +95,7 @@ static void lb_add(struct lease_table *lb)
 	write_unlock(&lease_list_lock);
 }
 
-static int alloc_lease(struct oplock_info *opinfo,
-	struct lease_ctx_info *lctx)
+static int alloc_lease(struct oplock_info *opinfo, struct lease_ctx_info *lctx)
 {
 	struct lease *lease;
 
@@ -236,8 +234,8 @@ int opinfo_write_to_read(struct oplock_info *opinfo)
 
 #ifdef CONFIG_SMB_INSECURE_SERVER
 	if (opinfo->is_smb2) {
-		if (!((opinfo->level == SMB2_OPLOCK_LEVEL_BATCH) ||
-			(opinfo->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE))) {
+		if (!(opinfo->level == SMB2_OPLOCK_LEVEL_BATCH ||
+		      opinfo->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE)) {
 			ksmbd_err("bad oplock(0x%x)\n", opinfo->level);
 			if (opinfo->is_lease)
 				ksmbd_err("lease state(0x%x)\n", lease->state);
@@ -248,16 +246,16 @@ int opinfo_write_to_read(struct oplock_info *opinfo)
 		if (opinfo->is_lease)
 			lease->state = lease->new_state;
 	} else {
-		if (!((opinfo->level == OPLOCK_EXCLUSIVE) ||
-			(opinfo->level == OPLOCK_BATCH))) {
+		if (!(opinfo->level == OPLOCK_EXCLUSIVE ||
+		      opinfo->level == OPLOCK_BATCH)) {
 			ksmbd_err("bad oplock(0x%x)\n", opinfo->level);
 			return -EINVAL;
 		}
 		opinfo->level = OPLOCK_READ;
 	}
 #else
-	if (!((opinfo->level == SMB2_OPLOCK_LEVEL_BATCH) ||
-	    (opinfo->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE))) {
+	if (!(opinfo->level == SMB2_OPLOCK_LEVEL_BATCH ||
+	      opinfo->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE)) {
 		ksmbd_err("bad oplock(0x%x)\n", opinfo->level);
 		if (opinfo->is_lease)
 			ksmbd_err("lease state(0x%x)\n", lease->state);
@@ -298,8 +296,8 @@ int opinfo_write_to_none(struct oplock_info *opinfo)
 
 #ifdef CONFIG_SMB_INSECURE_SERVER
 	if (opinfo->is_smb2) {
-		if (!((opinfo->level == SMB2_OPLOCK_LEVEL_BATCH) ||
-			(opinfo->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE))) {
+		if (!(opinfo->level == SMB2_OPLOCK_LEVEL_BATCH ||
+		      opinfo->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE)) {
 			ksmbd_err("bad oplock(0x%x)\n", opinfo->level);
 			if (opinfo->is_lease)
 				ksmbd_err("lease state(0x%x)\n",
@@ -310,16 +308,16 @@ int opinfo_write_to_none(struct oplock_info *opinfo)
 		if (opinfo->is_lease)
 			lease->state = lease->new_state;
 	} else {
-		if (!((opinfo->level == OPLOCK_EXCLUSIVE) ||
-			(opinfo->level == OPLOCK_BATCH))) {
+		if (!(opinfo->level == OPLOCK_EXCLUSIVE ||
+		      opinfo->level == OPLOCK_BATCH)) {
 			ksmbd_err("bad oplock(0x%x)\n", opinfo->level);
 			return -EINVAL;
 		}
 		opinfo->level = OPLOCK_NONE;
 	}
 #else
-	if (!((opinfo->level == SMB2_OPLOCK_LEVEL_BATCH) ||
-	    (opinfo->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE))) {
+	if (!(opinfo->level == SMB2_OPLOCK_LEVEL_BATCH ||
+	      opinfo->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE)) {
 		ksmbd_err("bad oplock(0x%x)\n", opinfo->level);
 		if (opinfo->is_lease)
 			ksmbd_err("lease state(0x%x)\n",
@@ -407,8 +405,7 @@ int lease_read_to_write(struct oplock_info *opinfo)
  *
  * Return:	0 on success, otherwise -EINVAL
  */
-static int lease_none_upgrade(struct oplock_info *opinfo,
-	__le32 new_state)
+static int lease_none_upgrade(struct oplock_info *opinfo, __le32 new_state)
 {
 	struct lease *lease = opinfo->o_lease;
 
@@ -474,7 +471,7 @@ void close_id_del_oplock(struct ksmbd_file *fp)
  * Return:      0
  */
 static void grant_write_oplock(struct oplock_info *opinfo_new, int req_oplock,
-	struct lease_ctx_info *lctx)
+		struct lease_ctx_info *lctx)
 {
 	struct lease *lease = opinfo_new->o_lease;
 
@@ -512,7 +509,7 @@ static void grant_write_oplock(struct oplock_info *opinfo_new, int req_oplock,
  * Return:      0
  */
 static void grant_read_oplock(struct oplock_info *opinfo_new,
-	struct lease_ctx_info *lctx)
+		struct lease_ctx_info *lctx)
 {
 	struct lease *lease = opinfo_new->o_lease;
 
@@ -542,7 +539,7 @@ static void grant_read_oplock(struct oplock_info *opinfo_new,
  * Return:      0
  */
 static void grant_none_oplock(struct oplock_info *opinfo_new,
-	struct lease_ctx_info *lctx)
+		struct lease_ctx_info *lctx)
 {
 	struct lease *lease = opinfo_new->o_lease;
 
@@ -562,14 +559,6 @@ static void grant_none_oplock(struct oplock_info *opinfo_new,
 	}
 }
 
-/**
- * find_opinfo() - find lease object for given client guid and lease key
- * @head:	oplock list(read,write or none) head
- * @guid1:	client guid of matching lease owner
- * @key1:	lease key of matching lease owner
- *
- * Return:      oplock(lease) object on success, otherwise NULL
- */
 static inline int compare_guid_key(struct oplock_info *opinfo,
 		const char *guid1, const char *key1)
 {
@@ -578,7 +567,7 @@ static inline int compare_guid_key(struct oplock_info *opinfo,
 	guid2 = opinfo->conn->ClientGUID;
 	key2 = opinfo->o_lease->lease_key;
 	if (!memcmp(guid1, guid2, SMB2_CLIENT_GUID_SIZE) &&
-			!memcmp(key1, key2, SMB2_LEASE_KEY_SIZE))
+	    !memcmp(key1, key2, SMB2_LEASE_KEY_SIZE))
 		return 1;
 
 	return 0;
@@ -594,7 +583,7 @@ static inline int compare_guid_key(struct oplock_info *opinfo,
  * Return:      oplock(lease) object on success, otherwise NULL
  */
 static struct oplock_info *same_client_has_lease(struct ksmbd_inode *ci,
-	char *client_guid, struct lease_ctx_info *lctx)
+		char *client_guid, struct lease_ctx_info *lctx)
 {
 	int ret;
 	struct lease *lease;
@@ -702,7 +691,7 @@ static int oplock_break_pending(struct oplock_info *opinfo, int req_op_level)
 
 static inline int allocate_oplock_break_buf(struct ksmbd_work *work)
 {
-	work->response_buf = ksmbd_alloc_response(MAX_CIFS_SMALL_BUFFER_SIZE);
+	work->response_buf = kzalloc(MAX_CIFS_SMALL_BUFFER_SIZE, GFP_KERNEL);
 	if (!work->response_buf)
 		return -ENOMEM;
 	work->response_sz = MAX_CIFS_SMALL_BUFFER_SIZE;
@@ -718,7 +707,7 @@ static inline int allocate_oplock_break_buf(struct ksmbd_work *work)
  * There are two ways this function can be called. 1- while file open we break
  * from exclusive/batch lock to levelII oplock and 2- while file write/truncate
  * we break from levelII oplock no oplock.
- * REQUEST_BUF(work) contains oplock_info.
+ * work->request_buf contains oplock_info.
  */
 static void __smb1_oplock_break_noti(struct work_struct *wk)
 {
@@ -726,7 +715,7 @@ static void __smb1_oplock_break_noti(struct work_struct *wk)
 	struct ksmbd_conn *conn = work->conn;
 	struct smb_hdr *rsp_hdr;
 	struct smb_com_lock_req *req;
-	struct oplock_info *opinfo = REQUEST_BUF(work);
+	struct oplock_info *opinfo = work->request_buf;
 
 	if (allocate_oplock_break_buf(work)) {
 		ksmbd_err("smb_allocate_rsp_buf failed! ");
@@ -735,7 +724,7 @@ static void __smb1_oplock_break_noti(struct work_struct *wk)
 	}
 
 	/* Init response header */
-	rsp_hdr = RESPONSE_BUF(work);
+	rsp_hdr = work->response_buf;
 	/* wct is 8 for locking andx(18) */
 	memset(rsp_hdr, 0, sizeof(struct smb_hdr) + 18);
 	rsp_hdr->smb_buf_length = cpu_to_be32(HEADER_SIZE_NO_BUF_LEN(conn)
@@ -756,19 +745,19 @@ static void __smb1_oplock_break_noti(struct work_struct *wk)
 	rsp_hdr->WordCount = 8;
 
 	/* Init locking request */
-	req = RESPONSE_BUF(work);
+	req = work->response_buf;
 
 	req->AndXCommand = 0xFF;
 	req->AndXReserved = 0;
 	req->AndXOffset = 0;
 	req->Fid = opinfo->fid;
 	req->LockType = LOCKING_ANDX_OPLOCK_RELEASE;
-	if (!opinfo->open_trunc && (opinfo->level == OPLOCK_BATCH ||
-			opinfo->level == OPLOCK_EXCLUSIVE))
+	if (!opinfo->open_trunc &&
+	    (opinfo->level == OPLOCK_BATCH ||
+	     opinfo->level == OPLOCK_EXCLUSIVE))
 		req->OplockLevel = 1;
-	else {
+	else
 		req->OplockLevel = 0;
-	}
 	req->Timeout = 0;
 	req->NumberOfUnlocks = 0;
 	req->ByteCount = 0;
@@ -815,21 +804,21 @@ static int smb1_oplock_break_noti(struct oplock_info *opinfo)
 #endif
 
 /**
- * smb2_oplock_break_noti() - send smb2 oplock break cmd from conn
+ * __smb2_oplock_break_noti() - send smb2 oplock break cmd from conn
  * to client
- * @work:     smb work object
+ * @wk:     smb work object
  *
  * There are two ways this function can be called. 1- while file open we break
  * from exclusive/batch lock to levelII oplock and 2- while file write/truncate
  * we break from levelII oplock no oplock.
- * REQUEST_BUF(work) contains oplock_info.
+ * work->request_buf contains oplock_info.
  */
 static void __smb2_oplock_break_noti(struct work_struct *wk)
 {
 	struct smb2_oplock_break *rsp = NULL;
 	struct ksmbd_work *work = container_of(wk, struct ksmbd_work, work);
 	struct ksmbd_conn *conn = work->conn;
-	struct oplock_break_info *br_info = REQUEST_BUF(work);
+	struct oplock_break_info *br_info = work->request_buf;
 	struct smb2_hdr *rsp_hdr;
 	struct ksmbd_file *fp;
 
@@ -843,12 +832,12 @@ static void __smb2_oplock_break_noti(struct work_struct *wk)
 	if (allocate_oplock_break_buf(work)) {
 		ksmbd_err("smb2_allocate_rsp_buf failed! ");
 		atomic_dec(&conn->r_count);
-		ksmbd_free_work_struct(work);
 		ksmbd_fd_put(work, fp);
+		ksmbd_free_work_struct(work);
 		return;
 	}
 
-	rsp_hdr = RESPONSE_BUF(work);
+	rsp_hdr = work->response_buf;
 	memset(rsp_hdr, 0, sizeof(struct smb2_hdr) + 2);
 	rsp_hdr->smb2_buf_length = cpu_to_be32(HEADER_SIZE_NO_BUF_LEN(conn));
 	rsp_hdr->ProtocolId = SMB2_PROTO_NUMBER;
@@ -863,13 +852,12 @@ static void __smb2_oplock_break_noti(struct work_struct *wk)
 	rsp_hdr->SessionId = 0;
 	memset(rsp_hdr->Signature, 0, 16);
 
-
-	rsp = RESPONSE_BUF(work);
+	rsp = work->response_buf;
 
 	rsp->StructureSize = cpu_to_le16(24);
 	if (!br_info->open_trunc &&
-			(br_info->level == SMB2_OPLOCK_LEVEL_BATCH ||
-			br_info->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE))
+	    (br_info->level == SMB2_OPLOCK_LEVEL_BATCH ||
+	     br_info->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE))
 		rsp->OplockLevel = SMB2_OPLOCK_LEVEL_II;
 	else
 		rsp->OplockLevel = SMB2_OPLOCK_LEVEL_NONE;
@@ -891,10 +879,9 @@ static void __smb2_oplock_break_noti(struct work_struct *wk)
 }
 
 /**
- * smb2_oplock_break() - send smb2 exclusive/batch to level2 oplock
+ * smb2_oplock_break_noti() - send smb2 exclusive/batch to level2 oplock
  *		break command from server to client
  * @opinfo:		oplock info object
- * @ack_required	if requiring ack
  *
  * Return:      0 on success, otherwise error
  */
@@ -939,13 +926,13 @@ static int smb2_oplock_break_noti(struct oplock_info *opinfo)
 /**
  * __smb2_lease_break_noti() - send lease break command from server
  * to client
- * @work:     smb work object
+ * @wk:     smb work object
  */
 static void __smb2_lease_break_noti(struct work_struct *wk)
 {
 	struct smb2_lease_break *rsp = NULL;
 	struct ksmbd_work *work = container_of(wk, struct ksmbd_work, work);
-	struct lease_break_info *br_info = REQUEST_BUF(work);
+	struct lease_break_info *br_info = work->request_buf;
 	struct ksmbd_conn *conn = work->conn;
 	struct smb2_hdr *rsp_hdr;
 
@@ -956,7 +943,7 @@ static void __smb2_lease_break_noti(struct work_struct *wk)
 		return;
 	}
 
-	rsp_hdr = RESPONSE_BUF(work);
+	rsp_hdr = work->response_buf;
 	memset(rsp_hdr, 0, sizeof(struct smb2_hdr) + 2);
 	rsp_hdr->smb2_buf_length = cpu_to_be32(HEADER_SIZE_NO_BUF_LEN(conn));
 	rsp_hdr->ProtocolId = SMB2_PROTO_NUMBER;
@@ -971,7 +958,7 @@ static void __smb2_lease_break_noti(struct work_struct *wk)
 	rsp_hdr->SessionId = 0;
 	memset(rsp_hdr->Signature, 0, 16);
 
-	rsp = RESPONSE_BUF(work);
+	rsp = work->response_buf;
 	rsp->StructureSize = cpu_to_le16(44);
 	rsp->Reserved = 0;
 	rsp->Flags = 0;
@@ -995,10 +982,9 @@ static void __smb2_lease_break_noti(struct work_struct *wk)
 }
 
 /**
- * smb2_break_lease() - break lease when a new client request
+ * smb2_lease_break_noti() - break lease when a new client request
  *			write lease
  * @opinfo:		conains lease state information
- * @ack_required:	if requring ack
  *
  * Return:	0 on success, otherwise error
  */
@@ -1061,10 +1047,8 @@ static void wait_lease_breaking(struct oplock_info *opinfo)
 	if (atomic_read(&opinfo->breaking_cnt)) {
 		int ret = 0;
 
-		ret = wait_event_interruptible_timeout(
-			opinfo->oplock_brk,
-			atomic_read(&opinfo->breaking_cnt) == 0,
-			HZ);
+		ret = wait_event_interruptible_timeout(opinfo->oplock_brk,
+			atomic_read(&opinfo->breaking_cnt) == 0, HZ);
 		if (!ret)
 			atomic_set(&opinfo->breaking_cnt, 0);
 	}
@@ -1123,26 +1107,23 @@ static int oplock_break(struct oplock_info *brk_opinfo, int req_op_level)
 			return err < 0 ? err : 0;
 
 		if (brk_opinfo->level == SMB2_OPLOCK_LEVEL_BATCH ||
-			brk_opinfo->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE)
+		    brk_opinfo->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE)
 			brk_opinfo->op_state = OPLOCK_ACK_WAIT;
 	}
 
 #ifdef CONFIG_SMB_INSECURE_SERVER
-	if (brk_opinfo->is_smb2) {
-		if (brk_opinfo->is_lease) {
+	if (brk_opinfo->is_smb2)
+		if (brk_opinfo->is_lease)
 			err = smb2_lease_break_noti(brk_opinfo);
-		} else {
+		else
 			err = smb2_oplock_break_noti(brk_opinfo);
-		}
-	} else {
+	else
 		err = smb1_oplock_break_noti(brk_opinfo);
-	}
 #else
-	if (brk_opinfo->is_lease) {
+	if (brk_opinfo->is_lease)
 		err = smb2_lease_break_noti(brk_opinfo);
-	} else {
+	else
 		err = smb2_oplock_break_noti(brk_opinfo);
-	}
 #endif
 
 	ksmbd_debug(OPLOCK, "oplock granted = %d\n", brk_opinfo->level);
@@ -1168,7 +1149,7 @@ void destroy_lease_table(struct ksmbd_conn *conn)
 
 	list_for_each_entry_safe(lb, lbtmp, &lease_table_list, l_entry) {
 		if (conn && memcmp(lb->client_guid, conn->ClientGUID,
-			SMB2_CLIENT_GUID_SIZE))
+				   SMB2_CLIENT_GUID_SIZE))
 			continue;
 again:
 		rcu_read_lock();
@@ -1203,7 +1184,7 @@ int find_same_lease_key(struct ksmbd_session *sess, struct ksmbd_inode *ci,
 
 	list_for_each_entry(lb, &lease_table_list, l_entry) {
 		if (!memcmp(lb->client_guid, sess->conn->ClientGUID,
-					SMB2_CLIENT_GUID_SIZE))
+			    SMB2_CLIENT_GUID_SIZE))
 			goto found;
 	}
 	read_unlock(&lease_list_lock);
@@ -1260,7 +1241,7 @@ static int add_lease_global_list(struct oplock_info *opinfo)
 	read_lock(&lease_list_lock);
 	list_for_each_entry(lb, &lease_table_list, l_entry) {
 		if (!memcmp(lb->client_guid, opinfo->conn->ClientGUID,
-			SMB2_CLIENT_GUID_SIZE)) {
+			    SMB2_CLIENT_GUID_SIZE)) {
 			opinfo->o_lease->l_lb = lb;
 			lease_add_list(opinfo);
 			read_unlock(&lease_list_lock);
@@ -1284,7 +1265,7 @@ static int add_lease_global_list(struct oplock_info *opinfo)
 }
 
 static void set_oplock_level(struct oplock_info *opinfo, int level,
-	struct lease_ctx_info *lctx)
+		struct lease_ctx_info *lctx)
 {
 	switch (level) {
 #ifdef CONFIG_SMB_INSECURE_SERVER
@@ -1293,8 +1274,7 @@ static void set_oplock_level(struct oplock_info *opinfo, int level,
 #endif
 	case SMB2_OPLOCK_LEVEL_BATCH:
 	case SMB2_OPLOCK_LEVEL_EXCLUSIVE:
-		grant_write_oplock(opinfo,
-			level, lctx);
+		grant_write_oplock(opinfo, level, lctx);
 		break;
 	case SMB2_OPLOCK_LEVEL_II:
 		grant_read_oplock(opinfo, lctx);
@@ -1307,22 +1287,19 @@ static void set_oplock_level(struct oplock_info *opinfo, int level,
 
 /**
  * smb_grant_oplock() - handle oplock/lease request on file open
- * @fp:		ksmbd file pointer
- * @oplock:	granted oplock type
- * @id:		fid of open file
- * @Tid:	Tree id of connection
- * @lctx:	lease context information on file open
- * @attr_only:	attribute only file open type
+ * @work:		smb work
+ * @req_op_level:	oplock level
+ * @pid:		id of open file
+ * @fp:			ksmbd file pointer
+ * @tid:		Tree id of connection
+ * @lctx:		lease context information on file open
+ * @share_ret:		share mode
  *
  * Return:      0 on success, otherwise error
  */
-int smb_grant_oplock(struct ksmbd_work *work,
-		     int req_op_level,
-		     uint64_t pid,
-		     struct ksmbd_file *fp,
-		     __u16 tid,
-		     struct lease_ctx_info *lctx,
-		     int share_ret)
+int smb_grant_oplock(struct ksmbd_work *work, int req_op_level, u64 pid,
+		struct ksmbd_file *fp, __u16 tid, struct lease_ctx_info *lctx,
+		int share_ret)
 {
 	struct ksmbd_session *sess = work->sess;
 	int err = 0;
@@ -1382,14 +1359,14 @@ int smb_grant_oplock(struct ksmbd_work *work,
 		prev_op_state = prev_opinfo->o_lease->state;
 
 	if (share_ret < 0 &&
-		(prev_opinfo->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE)) {
+	    prev_opinfo->level == SMB2_OPLOCK_LEVEL_EXCLUSIVE) {
 		err = share_ret;
 		opinfo_put(prev_opinfo);
 		goto err_out;
 	}
 
-	if ((prev_opinfo->level != SMB2_OPLOCK_LEVEL_BATCH) &&
-		(prev_opinfo->level != SMB2_OPLOCK_LEVEL_EXCLUSIVE)) {
+	if (prev_opinfo->level != SMB2_OPLOCK_LEVEL_BATCH &&
+	    prev_opinfo->level != SMB2_OPLOCK_LEVEL_EXCLUSIVE) {
 		opinfo_put(prev_opinfo);
 		goto op_break_not_needed;
 	}
@@ -1444,13 +1421,13 @@ err_out:
 }
 
 /**
- * smb_break_write_oplock() - break batch/exclusive oplock to level2
+ * smb_break_all_write_oplock() - break batch/exclusive oplock to level2
  * @work:	smb work
  * @fp:		ksmbd file pointer
- * @openfile:	open file object
+ * @is_trunc:	truncate on open
  */
 static void smb_break_all_write_oplock(struct ksmbd_work *work,
-	struct ksmbd_file *fp, int is_trunc)
+		struct ksmbd_file *fp, int is_trunc)
 {
 	struct oplock_info *brk_opinfo;
 
@@ -1458,7 +1435,7 @@ static void smb_break_all_write_oplock(struct ksmbd_work *work,
 	if (!brk_opinfo)
 		return;
 	if (brk_opinfo->level != SMB2_OPLOCK_LEVEL_BATCH &&
-		brk_opinfo->level != SMB2_OPLOCK_LEVEL_EXCLUSIVE) {
+	    brk_opinfo->level != SMB2_OPLOCK_LEVEL_EXCLUSIVE) {
 		opinfo_put(brk_opinfo);
 		return;
 	}
@@ -1472,21 +1449,20 @@ static void smb_break_all_write_oplock(struct ksmbd_work *work,
 /**
  * smb_break_all_levII_oplock() - send level2 oplock or read lease break command
  *	from server to client
- * @conn:	connection instance
+ * @work:	smb work
  * @fp:		ksmbd file pointer
  * @is_trunc:	truncate on open
  */
-void smb_break_all_levII_oplock(struct ksmbd_work *work,
-	struct ksmbd_file *fp, int is_trunc)
+void smb_break_all_levII_oplock(struct ksmbd_work *work, struct ksmbd_file *fp,
+		int is_trunc)
 {
 	struct oplock_info *op, *brk_op;
 	struct ksmbd_inode *ci;
 	struct ksmbd_conn *conn = work->sess->conn;
 
 	if (!test_share_config_flag(work->tcon->share_conf,
-			KSMBD_SHARE_FLAG_OPLOCKS)) {
+				    KSMBD_SHARE_FLAG_OPLOCKS))
 		return;
-	}
 
 	ci = fp->f_ci;
 	op = opinfo_get(fp);
@@ -1546,13 +1522,11 @@ void smb_break_all_levII_oplock(struct ksmbd_work *work,
 			goto next;
 #endif
 
-		if (op && op->is_lease &&
-			brk_op->is_lease &&
-			!memcmp(conn->ClientGUID, brk_op->conn->ClientGUID,
-				SMB2_CLIENT_GUID_SIZE) &&
-			!memcmp(op->o_lease->lease_key,
-				brk_op->o_lease->lease_key,
-				SMB2_LEASE_KEY_SIZE))
+		if (op && op->is_lease && brk_op->is_lease &&
+		    !memcmp(conn->ClientGUID, brk_op->conn->ClientGUID,
+			    SMB2_CLIENT_GUID_SIZE) &&
+		    !memcmp(op->o_lease->lease_key, brk_op->o_lease->lease_key,
+			    SMB2_LEASE_KEY_SIZE))
 			goto next;
 		brk_op->open_trunc = is_trunc;
 		oplock_break(brk_op, SMB2_OPLOCK_LEVEL_NONE);
@@ -1574,7 +1548,7 @@ next:
 void smb_break_all_oplock(struct ksmbd_work *work, struct ksmbd_file *fp)
 {
 	if (!test_share_config_flag(work->tcon->share_conf,
-			KSMBD_SHARE_FLAG_OPLOCKS))
+				    KSMBD_SHARE_FLAG_OPLOCKS))
 		return;
 
 	smb_break_all_write_oplock(work, fp, 1);
@@ -1590,21 +1564,23 @@ void smb_break_all_oplock(struct ksmbd_work *work, struct ksmbd_file *fp)
 __u8 smb2_map_lease_to_oplock(__le32 lease_state)
 {
 	if (lease_state == (SMB2_LEASE_HANDLE_CACHING_LE |
-		SMB2_LEASE_READ_CACHING_LE | SMB2_LEASE_WRITE_CACHING_LE))
+			    SMB2_LEASE_READ_CACHING_LE |
+			    SMB2_LEASE_WRITE_CACHING_LE)) {
 		return SMB2_OPLOCK_LEVEL_BATCH;
-	else if (lease_state != SMB2_LEASE_WRITE_CACHING_LE &&
-		lease_state & SMB2_LEASE_WRITE_CACHING_LE) {
+	} else if (lease_state != SMB2_LEASE_WRITE_CACHING_LE &&
+		 lease_state & SMB2_LEASE_WRITE_CACHING_LE) {
 		if (!(lease_state & SMB2_LEASE_HANDLE_CACHING_LE))
 			return SMB2_OPLOCK_LEVEL_EXCLUSIVE;
-	} else if (lease_state & SMB2_LEASE_READ_CACHING_LE)
+	} else if (lease_state & SMB2_LEASE_READ_CACHING_LE) {
 		return SMB2_OPLOCK_LEVEL_II;
+	}
 	return 0;
 }
 
 /**
  * create_lease_buf() - create lease context for open cmd response
  * @rbuf:	buffer to create lease context response
- * @lreq:	buffer to stored parsed lease state information
+ * @lease:	buffer to stored parsed lease state information
  */
 void create_lease_buf(u8 *rbuf, struct lease *lease)
 {
@@ -1631,7 +1607,6 @@ void create_lease_buf(u8 *rbuf, struct lease *lease)
 /**
  * parse_lease_state() - parse lease context containted in file open request
  * @open_req:	buffer containing smb2 file open(create) request
- * @lreq:	buffer to stored parsed lease state information
  *
  * Return:  oplock state, -ENOENT if create lease context not found
  */
@@ -1654,7 +1629,7 @@ struct lease_ctx_info *parse_lease_state(void *open_req)
 		cc = (struct create_context *)((char *)cc + next);
 		name = le16_to_cpu(cc->NameOffset) + (char *)cc;
 		if (le16_to_cpu(cc->NameLength) != 4 ||
-				strncmp(name, SMB2_CREATE_REQUEST_LEASE, 4)) {
+		    strncmp(name, SMB2_CREATE_REQUEST_LEASE, 4)) {
 			next = le32_to_cpu(cc->Next);
 			continue;
 		}
@@ -1679,7 +1654,7 @@ struct lease_ctx_info *parse_lease_state(void *open_req)
 /**
  * smb2_find_context_vals() - find a particular context info in open request
  * @open_req:	buffer containing smb2 file open(create) request
- * @str:	context name to search for
+ * @tag:	context name to search for
  *
  * Return:      pointer to requested context, NULL if @str context not found
  */
@@ -1711,7 +1686,7 @@ struct create_context *smb2_find_context_vals(void *open_req, const char *tag)
 }
 
 /**
- * create_durable_buf() - create durable handle context
+ * create_durable_rsp_buf() - create durable handle context
  * @cc:	buffer to create durable context response
  */
 void create_durable_rsp_buf(char *cc)
@@ -1734,8 +1709,9 @@ void create_durable_rsp_buf(char *cc)
 }
 
 /**
- * create_durable_buf() - create durable handle v2 context
+ * create_durable_v2_rsp_buf() - create durable handle v2 context
  * @cc:	buffer to create durable context response
+ * @fp: ksmbd file pointer
  */
 void create_durable_v2_rsp_buf(char *cc, struct ksmbd_file *fp)
 {
@@ -1756,13 +1732,12 @@ void create_durable_v2_rsp_buf(char *cc, struct ksmbd_file *fp)
 	buf->Name[3] = 'Q';
 
 	buf->Timeout = cpu_to_le32(fp->durable_timeout);
-	if (fp->is_persistent)
-		buf->Flags = SMB2_FLAGS_REPLAY_OPERATIONS;
 }
 
 /**
- * create_mxac_buf() - create query maximal access context
- * @cc:	buffer to create maximal access context response
+ * create_mxac_rsp_buf() - create query maximal access context
+ * @cc:			buffer to create maximal access context response
+ * @maximal_access:	maximal access
  */
 void create_mxac_rsp_buf(char *cc, int maximal_access)
 {
@@ -1786,10 +1761,6 @@ void create_mxac_rsp_buf(char *cc, int maximal_access)
 	buf->MaximalAccess = cpu_to_le32(maximal_access);
 }
 
-/**
- * create_mxac_buf() - create query maximal access context
- * @cc:	buffer to create query disk on id context response
- */
 void create_disk_id_rsp_buf(char *cc, __u64 file_id, __u64 vol_id)
 {
 	struct create_disk_id_rsp *buf;
@@ -1813,8 +1784,9 @@ void create_disk_id_rsp_buf(char *cc, __u64 file_id, __u64 vol_id)
 }
 
 /**
- * create_posix_buf() - create posix extension context
+ * create_posix_rsp_buf() - create posix extension context
  * @cc:	buffer to create posix on posix response
+ * @fp: ksmbd file pointer
  */
 void create_posix_rsp_buf(char *cc, struct ksmbd_file *fp)
 {
@@ -1868,7 +1840,7 @@ void create_posix_rsp_buf(char *cc, struct ksmbd_file *fp)
  * Return:      opinfo if found matching opinfo, otherwise NULL
  */
 struct oplock_info *lookup_lease_in_table(struct ksmbd_conn *conn,
-	char *lease_key)
+		char *lease_key)
 {
 	struct oplock_info *opinfo = NULL, *ret_op = NULL;
 	struct lease_table *lt;
@@ -1877,7 +1849,7 @@ struct oplock_info *lookup_lease_in_table(struct ksmbd_conn *conn,
 	read_lock(&lease_list_lock);
 	list_for_each_entry(lt, &lease_table_list, l_entry) {
 		if (!memcmp(lt->client_guid, conn->ClientGUID,
-			SMB2_CLIENT_GUID_SIZE))
+			    SMB2_CLIENT_GUID_SIZE))
 			goto found;
 	}
 
@@ -1890,12 +1862,11 @@ found:
 		if (!atomic_inc_not_zero(&opinfo->refcount))
 			continue;
 		rcu_read_unlock();
-		if (!opinfo->op_state ||
-			opinfo->op_state == OPLOCK_CLOSING)
+		if (!opinfo->op_state || opinfo->op_state == OPLOCK_CLOSING)
 			goto op_next;
 		if (!(opinfo->o_lease->state &
-			(SMB2_LEASE_HANDLE_CACHING_LE |
-			 SMB2_LEASE_WRITE_CACHING_LE)))
+		      (SMB2_LEASE_HANDLE_CACHING_LE |
+		       SMB2_LEASE_WRITE_CACHING_LE)))
 			goto op_next;
 		ret = compare_guid_key(opinfo, conn->ClientGUID,
 			lease_key);
@@ -1916,7 +1887,7 @@ out:
 }
 
 int smb2_check_durable_oplock(struct ksmbd_file *fp,
-	struct lease_ctx_info *lctx, char *name)
+		struct lease_ctx_info *lctx, char *name)
 {
 	struct oplock_info *opinfo = opinfo_get(fp);
 	int ret = 0;
@@ -1928,7 +1899,7 @@ int smb2_check_durable_oplock(struct ksmbd_file *fp,
 			goto out;
 		}
 		if (memcmp(opinfo->o_lease->lease_key, lctx->lease_key,
-					SMB2_LEASE_KEY_SIZE)) {
+			   SMB2_LEASE_KEY_SIZE)) {
 			ksmbd_err("invalid lease key\n");
 			ret = -EBADF;
 			goto out;
